/* A sample C program.
   It tests input via scanf(), with prompting.
   It also tests input and display of floating-point value.
   For GCCMU 1.1 or higher, or Waterloo C.

   Notes:
   - In WatC, the prompt msg does not have to end with \n, since
     WatC does a fflush(stdout) before a read on stdin.
     See $wcc:#32.g.$samread .
     However, it's probably better to end the prompt with \n,
     in case input is not conversational, or multiple scanf()
     calls are done on the same input record.
   - Currently in GCCMU, the prompt message must
     end with \n\n to get proper synchronization of
     prompts with conversational reads. PDPCLIB (mvssupa.asm)
     uses PUT-L (PUT in Locate mode) for all writes.
   - Floating-point input formats e,f,g are supported in GCCMU 1.1
     and PDPCLIB 0.84, for example %lf to read a double value.
     The "l" (long) modifier should be used for double variables
     and omitted for float variables.
   - Input format type characters supported in GCCMU 1.1:
     d (integer), s (string), u (unsigned int), c (char),
     and e, E, g, G, f (floating-point). Modifier chars l and h
     are supported.
   - In GCCMU 1.0 and 1.1, scanf() skips an invalid char (it should not).
     For example, if x123 is entered, the first call to scanf()
     does not set a value, but the next call sets value 123.
   - On MUSIC/SP EOF can be indicated by entering /eof or /EOF
     on a conversational read (unit 9).
   - If 123xx or 123 xx is entered, value 123 is found, but
     the next scanf() fails with nitems 0.
   - Currently in GCCMU, fflush() is ignored for an input stream.
*/
#include <stdio.h>
int main(void)
{
int n,nitems,num;
double xval;
char ch1;

printf("Integer read loop, using scanf().\n");
printf("Will stop after 10 iterations.\n");
for(num=0;num<10;num++)
  {
    printf("Enter an integer or -9999 to end this loop:\n\n");
    n=-99999;  /* in case nothing is set by scanf() */
    nitems=scanf("%d",&n);
    printf("Function return value from scanf() is nitems=%d\n",
           nitems);
    if(nitems<0)
      { /* scanf() returns EOF (= -1) if i/o error or EOF */
        printf("** scanf() returned nitems=%d (probably EOF)\n",
               nitems);
        break;
      }
    if(nitems==0)
      { printf("** scanf() returned nitems=0 (no value found)\n");
      }
    printf("Value found: %d\n",n);
    if(n==-9999) break;
  }

/* Try reading a double floating-point value */
printf("\nFloating-point read loop.\nWill stop after 10 iterations.\n");
for(num=0;num<10;num++)
  { printf("Enter a floating-point value or -9999 to end:\n\n");
    xval=-99999.;  /* in case nothing entered */
    nitems=scanf("%lf",&xval);
    printf("Function return value from scanf() is nitems=%d\n",
           nitems);
    if(nitems<0) break;  /* probably EOF or error */
    printf("Result value (by format %%0.7lf): xval=%0.7lf\n",xval);
    if(xval==-9999.) break;
  }

/* Try reading a character */
printf("\nCharacter read loop.\nWill stop after 10 iterations.\n");
for(num=0;num<10;num++)
  { printf("Enter a character or x to end:\n\n");
    ch1='$';   /* in case nothing entered */
    nitems=scanf("%c",&ch1);
    printf("Function return value from scanf() is nitems=%d\n",nitems);
    if(nitems<0) break;  /* probably EOF */
    printf("Result character = %c\n",ch1);
    if(ch1=='x') break;
  }

return 0;
}
